@@ -97,7 +97,7 @@ class BlackBody(Fittable1DModel):
     }
 
     def __init__(self, *args, **kwargs):
-        scale = kwargs.get("scale", None)
+        scale = kwargs.get("scale")
 
         # Support scale with non-dimensionless unit by stripping the unit and
         # storing as self._output_units.
@@ -318,10 +318,7 @@ class Drude1D(Fittable1DModel):
                 (1 / x_0)
                 + d_amplitude
                 * (x_0**2 / fwhm**2)
-                * (
-                    (-x / x_0 - 1 / x) * (x / x_0 - x_0 / x)
-                    - (2 * fwhm**2 / x_0**3)
-                )
+                * ((-x / x_0 - 1 / x) * (x / x_0 - x_0 / x) - (2 * fwhm**2 / x_0**3))
             )
         )
         d_fwhm = (2 * amplitude * d_amplitude / fwhm) * (1 - d_amplitude)
@@ -346,12 +343,13 @@ class Drude1D(Fittable1DModel):
             return None
         return {self.outputs[0]: self.amplitude.unit}
 
-    @x_0.validator
-    def x_0(self, val):
+    def _x_0_validator(self, val):
         """Ensure `x_0` is not 0."""
         if np.any(val == 0):
             raise InputParameterError("0 is not an allowed value for x_0")
 
+    x_0._validator = _x_0_validator
+
     def bounding_box(self, factor=50):
         """Tuple defining the default ``bounding_box`` limits,
         ``(x_low, x_high)``.
