@@ -2,6 +2,7 @@
 """
 Test Structured units and quantities.
 """
+
 import copy
 
 import numpy as np
@@ -13,7 +14,6 @@ from astropy import units as u
 from astropy.tests.helper import check_pickling_recovery, pickle_protocol  # noqa: F401
 from astropy.units import Quantity, StructuredUnit, Unit, UnitBase
 from astropy.units.quantity import _structured_unit_like_dtype
-from astropy.utils.compat import NUMPY_LT_1_21_1
 from astropy.utils.masked import Masked
 
 
@@ -245,7 +245,6 @@ class TestStructuredUnitsCopyPickle(StructuredTestBaseWithUnits):
         assert su_copy == self.pv_t_unit
         assert su_copy._units is not self.pv_t_unit._units
 
-    @pytest.mark.skipif(NUMPY_LT_1_21_1, reason="https://stackoverflow.com/q/69571643")
     def test_pickle(self, pickle_protocol):  # noqa: F811
         check_pickling_recovery(self.pv_t_unit, pickle_protocol)
 
@@ -290,11 +289,11 @@ class TestStructuredUnitAsMapping(StructuredTestBaseWithUnits):
 
 class TestStructuredUnitMethods(StructuredTestBaseWithUnits):
     def test_physical_type_id(self):
-        pv_ptid = self.pv_unit._get_physical_type_id()
+        pv_ptid = self.pv_unit._physical_type_id
         assert len(pv_ptid) == 2
         assert pv_ptid.dtype.names == ("p", "v")
-        p_ptid = self.pv_unit["p"]._get_physical_type_id()
-        v_ptid = self.pv_unit["v"]._get_physical_type_id()
+        p_ptid = self.pv_unit["p"]._physical_type_id
+        v_ptid = self.pv_unit["v"]._physical_type_id
         # Expected should be (subclass of) void, with structured object dtype.
         expected = np.array((p_ptid, v_ptid), [("p", "O"), ("v", "O")])[()]
         assert pv_ptid == expected
@@ -306,8 +305,8 @@ class TestStructuredUnitMethods(StructuredTestBaseWithUnits):
         assert pv_ptid[0] == p_ptid
         assert pv_ptid[1] == v_ptid
         # More complicated version.
-        pv_t_ptid = self.pv_t_unit._get_physical_type_id()
-        t_ptid = self.t_unit._get_physical_type_id()
+        pv_t_ptid = self.pv_t_unit._physical_type_id
+        t_ptid = self.t_unit._physical_type_id
         assert pv_t_ptid == np.array((pv_ptid, t_ptid), "O,O")[()]
         assert pv_t_ptid["pv"] == pv_ptid
         assert pv_t_ptid["t"] == t_ptid
