@@ -1,7 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Sundry function and class decorators."""
 
-
 import functools
 import inspect
 import textwrap
@@ -37,6 +36,8 @@ def deprecated(
     pending=False,
     obj_type=None,
     warning_type=AstropyDeprecationWarning,
+    *,
+    pending_warning_type=AstropyPendingDeprecationWarning,
 ):
     """
     Used to mark a function or class as deprecated.
@@ -46,8 +47,8 @@ def deprecated(
     Parameters
     ----------
     since : str
-        The release at which this API became deprecated.  This is
-        required.
+        The release at which this API became deprecated.
+        This is required.
 
     message : str, optional
         Override the default deprecation message.  The format
@@ -74,7 +75,7 @@ def deprecated(
         tell the user about this alternative if provided.
 
     pending : bool, optional
-        If True, uses a AstropyPendingDeprecationWarning instead of a
+        If True, uses a ``pending_warning_type`` instead of a
         ``warning_type``.
 
     obj_type : str, optional
@@ -84,6 +85,11 @@ def deprecated(
     warning_type : Warning
         Warning to be issued.
         Default is `~astropy.utils.exceptions.AstropyDeprecationWarning`.
+
+    pending_warning_type : Warning
+        Pending warning to be issued.
+        This only works if ``pending`` is set to True.
+        Default is `~astropy.utils.exceptions.AstropyPendingDeprecationWarning`.
     """
     method_types = (classmethod, staticmethod, types.MethodType)
 
@@ -125,7 +131,7 @@ def deprecated(
 
         def deprecated_func(*args, **kwargs):
             if pending:
-                category = AstropyPendingDeprecationWarning
+                category = pending_warning_type
             else:
                 category = warning_type
 
@@ -236,6 +242,7 @@ def deprecated_attribute(
     alternative=None,
     pending=False,
     warning_type=AstropyDeprecationWarning,
+    pending_warning_type=AstropyPendingDeprecationWarning,
 ):
     """
     Used to mark a public attribute as deprecated.  This creates a
@@ -273,6 +280,11 @@ def deprecated_attribute(
         Warning to be issued.
         Default is `~astropy.utils.exceptions.AstropyDeprecationWarning`.
 
+    pending_warning_type : Warning
+        Pending warning to be issued.
+        This only works if ``pending`` is set to True.
+        Default is `~astropy.utils.exceptions.AstropyPendingDeprecationWarning`.
+
     Examples
     --------
     ::
@@ -302,6 +314,7 @@ def deprecated_attribute(
         alternative=alternative,
         pending=pending,
         warning_type=warning_type,
+        pending_warning_type=pending_warning_type,
     )
 
     @specific_deprecated
@@ -861,7 +874,7 @@ class lazyproperty(property):
 
 class sharedmethod(classmethod):
     """
-    This is a method decorator that allows both an instancemethod and a
+    This is a method decorator that allows both an instance method and a
     `classmethod` to share the same name.
 
     When using `sharedmethod` on a method defined in a class's body, it
@@ -888,7 +901,7 @@ class sharedmethod(classmethod):
         additional args were (3, 4)
 
     This also supports a more advanced usage, where the `classmethod`
-    implementation can be written separately.  If the class's *metaclass*
+    implementation can be written separately.  If the class' *metaclass*
     has a method of the same name as the `sharedmethod`, the version on
     the metaclass is delegated to::
 
